#pragma once

#define CAMERA_TRIGGER_CONTINUE 0
#define CAMERA_TRIGGER_HARDWARE 1
#define CAMERA_TRIGGER_LEVEL 4
#define CAMERA_TRIGGER_SOFTWARE 5

namespace eda {

typedef int(*img_Callback)(char *img_buff, int img_len);

enum CameraName{
    AR0234, OV2311
};
class Camera
{
public:
    Camera(){};
    virtual ~Camera(){};

    /**
     * @brief 初始化摄像头
     * 
     * @param mode 0 - 连续工作模式; 1 - 硬件触发模式； 5 - 软件触发模式
     * @param width 
     * @param height 
     * @return int 
     */
    virtual int open(int mode, int width, int height) = 0;
    /**
     * @brief 关闭摄像头
     * 
     * @return int 
     */
    virtual int close() = 0;

    /**
     * @brief 设置曝光时间
     * 
     * @param exp_value 
     * @return int 
     */
    virtual int set_exposure(int exp_value) = 0;
    /**
     * @brief 获取曝光时间
     * 
     * @param exp_value 
     * @return int 
     */
    virtual int get_exposure(int *exp_value) = 0;

    /**
     * @brief 设置增益
     * 
     * @param gain_value 
     * @return int 
     */
    virtual int set_gain(int gain_value) = 0;
    /**
     * @brief 获取增益
     * 
     * @param gain_value 
     * @return int 
     */
    virtual int get_gain(int *gain_value) = 0;

     /**
     * @brief 注册回调函数，获取图像数据
     * 
     * @param callback 
     * @return int 
     */
    virtual int callback_image_ready(img_Callback callback)=0;

    virtual CameraName name() = 0;

    virtual int call_trigger()=0;
};

}